@@ -251,31 +251,54 @@ class SunSynkLoggerAPI:
             self.settingsData.append(settings)
         _LOGGER.debug(settings)
         return settings  
-        
+
+    async def readInverterCustom(self, sn: str, params) -> Optional(dict):
+        """Get Inverter Custom"""
+        _LOGGER.debug("Retrieving Custom Data for Serial : %s", sn)
+        today = datetime.today()
+        d = today.strftime("%Y-%m-%d")
+        custom =  await self.__get(path="api/v1/inverter/" + sn + "/day?sn=" + sn + "&date="+ d+ "&edate="+ d+ "&lan=en&params="+params)
+        _LOGGER.debug(custom)
+        return custom
+
     def __getInverterSensors(self, inverter) -> Sensors:
         sensors: Sensors = []
         sensors.append( Sensor (  key = inverter["sn"]  +"_status", name = "Inverter Status", value = inverter["status"] ) )
         sensors.append( Sensor (  key = inverter["sn"]  +"_pac", name = "Inverter Energy", unit =WATT , value = inverter["pac"]) )
         sensors.append( Sensor (  key = inverter["sn"]  +"_etoday", name = "Inverter Energy Today", unit = KWATT_HOUR,  value = inverter["etoday"]) )
+        #sensors.append( Sensor (  key = inverter["sn"]  +"_emonth", name = "Inverter Energy Month", unit = KWATT_HOUR,  value = inverter["emonth"]) )
         sensors.append( Sensor (  key = inverter["sn"]  +"_etotal", name = "Inverter Energy Total", unit = KWATT_HOUR, value = inverter["etotal"]) )
+        #sensors.append( Sensor (  key = inverter["sn"]  +"_runstatus", name = "Inverter Run Status", unit = KWATT_HOUR, value = inverter["runStatus"]) )
+        return sensors
+
+    async def __getInverterCustomSensors(self,inverter) -> Sensors:
+        sensors: Sensors = []
+        params="21,29,79,23,88,20"
+        custData = await self.readInverterCustom(inverter["sn"] ,params)
+        for p in custData["infos"]:
+            sensors.append( Sensor (  key = inverter["sn"]  +"_custom_" + p["label"], name = "Inverter Data " + p["label"], unit = WATT, value = p["records"][-1]["value"]) )
         return sensors
 
     def __getInverterInputSensors(self,inverter) -> Sensors:
         sensors: Sensors = []
-        sensors.append( Sensor (  key = inverter["sn"] +"_solar_power", name = "Solar Energy", unit =WATT , value = inverter["pac"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_solar_today", name = "Solar Energy Today", unit =KWATT_HOUR , value = inverter["etoday"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_solar_total", name = "Solar Energy Total", unit =KWATT_HOUR , value = inverter["etotal"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pac", name = "Input P-ac", unit =WATT , value = inverter["pac"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_eToday", name = "Input eToday", unit =KWATT_HOUR , value = inverter["etoday"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_eTotal", name = "Input eTotal", unit =KWATT_HOUR , value = inverter["etotal"]) )
 
         inverter_index = self.getInverterIndex(inverter["sn"])
         inData = self.inputData[inverter_index]
         _LOGGER.debug(inData)
 
-        sensors.append( Sensor (  key = inverter["sn"] +"_pv1_power", name = "P-pv-L1", unit =WATT , value = inData["pvIV"][0]["ppv"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_pv1_current", name = "I-pv-L1", unit = AMPERE , value = inData["pvIV"][0]["ipv"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_pv1_voltage", name = "V-pv-L1", unit =VOLT , value = inData["pvIV"][0]["vpv"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_pv2_power", name = "P-pv-L2", unit =WATT , value = inData["pvIV"][1]["ppv"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_pv2_current", name = "I-pv-L2", unit =AMPERE , value = inData["pvIV"][1]["ipv"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_pv2_voltage", name = "V-pv-L2", unit =VOLT , value = inData["pvIV"][1]["vpv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv1_power", name = "P-pv-L1", unit =WATT , value = inData["pvIV"][0]["ppv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv1_current", name = "I-pv-L1", unit = AMPERE , value = inData["pvIV"][0]["ipv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv1_voltage", name = "V-pv-L1", unit =VOLT , value = inData["pvIV"][0]["vpv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv1_todayPV", name = "P-pv-L1-Today", unit =KWATT_HOUR , value = inData["pvIV"][0]["todayPv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv2_power", name = "P-pv-L2", unit =WATT , value = inData["pvIV"][1]["ppv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv2_current", name = "I-pv-L2", unit =AMPERE , value = inData["pvIV"][1]["ipv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv2_voltage", name = "V-pv-L2", unit =VOLT , value = inData["pvIV"][1]["vpv"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_input_pv2_todayPV", name = "P-pv-L2-Today", unit =KWATT_HOUR , value = inData["pvIV"][1]["todayPv"]) )
+
+
         return sensors
 
     def __getInverterOutputSensors(self,inverter) -> Sensors:
@@ -285,10 +308,11 @@ class SunSynkLoggerAPI:
         outData = self.outputData[inverter_index]
         _LOGGER.debug (outData)
 
-        sensors.append( Sensor (  key = inverter["sn"] +"_output_power", name = "P-ac-L1", unit = WATT , value = outData["pac"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_output_current", name = "I-ac-L1", unit =AMPERE , value = outData["vip"][0]["current"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_output_voltage", name = "V-ac-L1", unit =VOLT , value = outData["vip"][0]["volt"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_output_power", name = "Output Power", unit = WATT , value = outData["pac"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_output_current", name = "Output Current", unit =AMPERE , value = outData["vip"][0]["current"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_output_voltage", name = "Output Voltage", unit =VOLT , value = outData["vip"][0]["volt"]) )
         sensors.append( Sensor (  key = inverter["sn"] +"_output_frequency", name = "Output Frequency", unit = HERTZ , value = outData["fac"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_output_pInv", name = "Output pInv", unit = WATT , value = outData["pInv"]) )
 
         return sensors
 
@@ -320,7 +344,9 @@ class SunSynkLoggerAPI:
         
         sensors.append( Sensor (  key = inverter["sn"] +"_load_totalUsed", name = "Load Total Used", unit =KWATT_HOUR , value = loadData["totalUsed"]) )
         sensors.append( Sensor (  key = inverter["sn"] +"_load_dailyUsed", name = "Load Used Daily", unit =KWATT_HOUR , value = loadData["dailyUsed"]) )
-        sensors.append( Sensor (  key = inverter["sn"] +"_load_totalPower", name = "Load Power", unit =WATT , value = loadData["totalPower"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_load_totalPower", name = "Load Total Power", unit =WATT , value = loadData["totalPower"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_smartload", name = "Smartload Status", value = loadData["smartLoadStatus"]) )
+        sensors.append( Sensor (  key = inverter["sn"] +"_load_fac", name = "Load Frequency", unit =HERTZ , value = loadData["loadFac"]) )
         sensors.append( Sensor (  key = inverter["sn"] +"_load_upsPower", name = "UPS Total Power", unit =WATT , value = loadData["upsPowerTotal"]) )
         sensors.append( Sensor (  key = inverter["sn"] +"_load_voltage", name = "V-L1", unit =VOLT , value = loadData["vip"][0]["volt"]) )
         sensors.append( Sensor (  key = inverter["sn"] +"_load_current", name = "I-L1", unit =AMPERE , value = loadData["vip"][0]["current"]) )
@@ -359,6 +385,7 @@ class SunSynkLoggerAPI:
         inverter_index=self.getInverterIndex(serial)
         inv = self.inverters[inverter_index]
         sen.add( self.__getInverterSensors(inv))
+        sen.add( await self.__getInverterCustomSensors(inv))
         sen.add( self.__getInverterInputSensors(inv))
         sen.add( self.__getInverterOutputSensors(inv))
         sen.add( self.__getInverterGridSensors(inv))
